# Models of Brittle-Matrix-Composite Beams

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/bmcs-group/bmcs_beam/master?urlpath=%2Fapps%2Fbmcs_beam/bending/deflection_profile.ipynb) - Start a simple example
